//+------------------------------------------------------------------+
//|                OzFx Squeeze-More Expert Advisor for MetaTrader 4 |
//|                                               version 1.02 beta2 |
//|                                          original idea from OzFx |
//|                                           EA conversion by Azmel |
//+------------------------------------------------------------------+
//| INSTRUCTIONS                                                     |
//| To be used on any chart on H4 timeframe.                         |
//+------------------------------------------------------------------+
//| VERSION HISTORY                                                  |
//| 1.00  - Initial version of OzFx Squeeze-More with Aggressive     |
//|         settings.                                                |
//| 1.01  - Fixed entry bug.                                         |
//| 1.02  - Fixed two-signal bug. New MM routine.                    |
//| 1.02 beta - variable SL and TP for optimisation.                 |
//| 1.02 beta2 - Variable Stoch Upper and Lower for optimisation.    |
//+------------------------------------------------------------------+

#include <stdlib.mqh>

#define SIGNAL_NONE 0
#define SIGNAL_BUY  1
#define SIGNAL_SELL 2
#define SIGNAL_WAIT 3

//+------------------------------------------------------------------+
//| External Variables                                               |
//+------------------------------------------------------------------+

extern int    Magic           = 887425;
extern double Lots            = 0.01;
extern int    TakeProfit      = 50;
extern int    StopLoss        = 50;
extern bool   MoneyManagement = true;
extern int    Risk            = 1;
extern bool   StrongMode      = false;
extern double StU = 80;
extern double StL = 20;

//+------------------------------------------------------------------+
//| Internal variables                                               |
//+------------------------------------------------------------------+

double MaxLots;

int    i;
int    OpenOrders;
int    Order;

int    ticket1;
int    ticket2;
int    ticket3;

double ACC;
double ACP;
double ACH;
double AOC;
double AOP;
double AOH;
double StM;
double StS;

int    TP1;
int    TP2;

int    SL;

int    slippage = 5;

//+------------------------------------------------------------------+
//| Main code                                                        |
//+------------------------------------------------------------------+

int start()
{
   TP1=TakeProfit;
   TP2=TP1+TakeProfit;
   SL=StopLoss;
   
   //+---------------------------------------------------------------+
   //| Money Management Routine                                      |
   //+---------------------------------------------------------------+

   if (MoneyManagement)
   {
      Lots=MathFloor((AccountBalance()*Risk)/(MarketInfo(Symbol(),MODE_LOTSIZE)*MarketInfo(Symbol(),MODE_MINLOT)))*MarketInfo(Symbol(),MODE_MINLOT);
   }
   

   //+---------------------------------------------------------------+
   //| Time Frame Check                                              |
   //+---------------------------------------------------------------+
   
   if (Period() != 240)
   {
      Comment("Wrong Time Frame. Please switch to H4.");
      return(0);
   }
   
   //+---------------------------------------------------------------+
   //| Main Trading Routine                                          |
   //+---------------------------------------------------------------+

   //+---------------------------------------------------------------+
   //| Signal & Indicators                                           |
   //+---------------------------------------------------------------+

   ACC = iAC(NULL,0,0);
   ACP = iAC(NULL,0,1);
   ACH = iAC(NULL,0,2);
   AOC = iAO(NULL,0,0);
   AOP = iAO(NULL,0,1);
   AOH = iAO(NULL,0,2);
   StM = iStochastic(NULL,0,5,3,3,MODE_SMA,0,MODE_MAIN  ,0);
   StS = iStochastic(NULL,0,5,3,3,MODE_SMA,0,MODE_SIGNAL,0);
      
   Comment("\nOzFx Squeeze-More version 1.02 beta2\nCopyright  2008 OzFx\nEA Conversion by Azmel\n\nTrading ",Lots," Lots");

   //+---------------------------------------------------------------+
   //| Signal Confirmation Routine                                   |
   //+---------------------------------------------------------------+
      
   if(Order==SIGNAL_NONE)
   {
      if(StrongMode)
      {
         if(ACC>ACP && ACP<ACH && AOC>AOP && AOP<AOH && ACC<0 && AOC<0 && StM<=StL && StS<=StL)
         {
            Order=SIGNAL_BUY;
            ticket1=-1;
            ticket2=-1;
            ticket3=-1;
         }
         else
         {
            if(ACC<ACP && ACP>ACH && AOC<AOP && AOP>AOH && ACC>0 && AOC>0 && StM>=StU && StS>=StU)
            {
               Order=SIGNAL_SELL;
               ticket1=-1;
               ticket2=-1;
               ticket3=-1;
            }
         }
      }
      else
      {
         if(ACC>ACP && ACP<ACH && ACC<0 && StM<=StL && StS<=StL)
         {
            Order=SIGNAL_BUY;
            ticket1=-1;
            ticket2=-1;
            ticket3=-1;
         }
         else
         {
            if(ACC<ACP && ACP>ACH && ACC>0 && StM>=StU && StS>=StU)
            {
               Order=SIGNAL_SELL;
               ticket1=-1;
               ticket2=-1;
               ticket3=-1;
            }
         }
      }
   }

   //+---------------------------------------------------------------+
   //| Buy Routine                                                   |
   //+---------------------------------------------------------------+
   
   if(Order==SIGNAL_BUY)
   {
      for(i=0;i<OrdersTotal();i++)
      {
         OrderSelect(i,SELECT_BY_POS,MODE_TRADES);
         if(OrderSymbol()==Symbol() && OrderMagicNumber()==Magic && OrderType()==OP_SELL)
         {
            OrderClose(OrderTicket(),OrderLots(),Ask,slippage,CLR_NONE);
         }
      }
      
      if(ticket1==-1)
      {
         ticket1=OrderSend(Symbol(),OP_BUY,Lots,Ask,slippage,Ask-SL*Point,Ask+TP1*Point,"OzFxSM-1B",Magic,CLR_NONE);
      }
      if(ticket2==-1)
      {
         ticket2=OrderSend(Symbol(),OP_BUY,Lots,Ask,slippage,Ask-SL*Point,Ask+TP2*Point,"OzFxSM-2B",Magic,CLR_NONE);
      }
      if(ticket3==-1)
      {
         ticket3=OrderSend(Symbol(),OP_BUY,Lots,Ask,slippage,Ask-SL*Point,0            ,"OzFxSM-3B",Magic,CLR_NONE);
      }
      if(ticket1!=-1 && ticket2!=-1 && ticket3!=-1 && Minute()>5)
      {
         Order=SIGNAL_WAIT;
      }
   }
   
   //+---------------------------------------------------------------+
   //| Sell Routine                                                  |
   //+---------------------------------------------------------------+

   if(Order==SIGNAL_SELL)
   {
      for(i=0;i<OrdersTotal();i++)
      {
         OrderSelect(i,SELECT_BY_POS,MODE_TRADES);
         if(OrderSymbol()==Symbol() && OrderMagicNumber()==Magic && OrderType()==OP_BUY)
         {
            OrderClose(OrderTicket(),OrderLots(),Bid,slippage,CLR_NONE);
         }
      }
      
      if(ticket1==-1)
      {
         ticket1=OrderSend(Symbol(),OP_SELL,Lots,Bid,slippage,Bid+SL*Point,Bid-TP1*Point,"OzFxSM-1S",Magic,CLR_NONE);
      }
      if(ticket2==-1)
      {
         ticket2=OrderSend(Symbol(),OP_SELL,Lots,Bid,slippage,Bid+SL*Point,Bid-TP2*Point,"OzFxSM-2S",Magic,CLR_NONE);
      }
      if(ticket3==-1)
      {
         ticket3=OrderSend(Symbol(),OP_SELL,Lots,Bid,slippage,Bid+SL*Point,0            ,"OzFxSM-3S",Magic,CLR_NONE);
      }
      if(ticket1!=-1 && ticket2!=-1 && ticket3!=-1 && Minute()>5)
      {
         Order=SIGNAL_WAIT;
      }
   }
   
   //+---------------------------------------------------------------+
   //| Move to Break Even Routine                                    |
   //+---------------------------------------------------------------+

   for(i=0;i<OrdersTotal();i++)
   {
      OrderSelect(i,SELECT_BY_POS,MODE_TRADES);
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==Magic)
      {
         if(OrderType()==OP_BUY && OrderOpenPrice()>OrderStopLoss() && Bid>=OrderOpenPrice()+50*Point)
         {
            OrderModify(OrderTicket(),OrderOpenPrice(),OrderOpenPrice(),OrderTakeProfit(),0,CLR_NONE);
         }
         if(OrderType()==OP_SELL && OrderOpenPrice()<OrderStopLoss() && Ask<=OrderOpenPrice()-50*Point)
         {
            OrderModify(OrderTicket(),OrderOpenPrice(),OrderOpenPrice(),OrderTakeProfit(),0,CLR_NONE);
         }
      }
   }

   //+---------------------------------------------------------------+
   //| Reset Trade Routine                                           |
   //+---------------------------------------------------------------+
   
   if(Order==SIGNAL_WAIT)
   {
      if(Hour()==0 || Hour()==4 || Hour()==8 || Hour()==12 || Hour()==16 || Hour()==20)
      {
         if(Minute()<5)
         {
            Order=SIGNAL_NONE;
         }
      }
   }
   return(0);
}